@@ -1,4 +1,4 @@
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 import jwt
 from pythonit_toolkit.pastaporto.entities import Credential
@@ -11,7 +11,7 @@ def fake_pastaporto_token_for_user(
     if staff:
         credentials.append(Credential.STAFF)
 
-    now = datetime.utcnow()
+    now = datetime.now(timezone.utc)
     return jwt.encode(
         {
             "userInfo": {"id": user["id"], "email": user["email"]},
@@ -26,7 +26,7 @@ def fake_pastaporto_token_for_user(
 
 
 def fake_service_to_service_token(secret: str, *, issuer: str, audience: str):
-    now = datetime.utcnow()
+    now = datetime.now(timezone.utc)
     return jwt.encode(
         {
             "iss": issuer,
